# gasm-tool-json2mermaid

A utility to convert gASM JSON graph exports to Mermaid diagram format.

See [https://github.com/mathiscode/gasm](https://github.com/mathiscode/gasm) for more information.

## Installation

```bash
pip install gasm-tool-json2mermaid
```

## Usage

```bash
gasm-json2mermaid graph.json > graph.mmd
```
